==> unit-1.0.41-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractSourceLegendTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractSourceLegendTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _44_1_01300019320 _44_1_01300019320;
	public SourceLegendTemplate._44_1_01300019320. _44_58_11953754543 _44_58_11953754543;
	public SourceLegendTemplate._44_1_01300019320. _44_181_0845344845 _44_181_0845344845;
	public _45_1_0862779871 _45_1_0862779871;
	public SourceLegendTemplate._45_1_0862779871. _45_58_11647597214 _45_58_11647597214;
	public SourceLegendTemplate._45_1_0862779871. _45_181_0604353253 _45_181_0604353253;
	public _46_1_11332481393 _46_1_11332481393;
	public SourceLegendTemplate._46_1_11332481393. _46_58_11593277622 _46_58_11593277622;
	public SourceLegendTemplate._46_1_11332481393. _46_181_12119083845 _46_181_12119083845;

    public AbstractSourceLegendTemplate(B box) {
        super(box);
        id("sourceLegendTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (_44_1_01300019320 == null) _44_1_01300019320 = register(new _44_1_01300019320(box()).<_44_1_01300019320>id("a_2051942081").owner(AbstractSourceLegendTemplate.this));
		if (_44_1_01300019320 != null) _44_58_11953754543 = _44_1_01300019320._44_58_11953754543;
		if (_44_1_01300019320 != null) _44_181_0845344845 = _44_1_01300019320._44_181_0845344845;
		if (_45_1_0862779871 == null) _45_1_0862779871 = register(new _45_1_0862779871(box()).<_45_1_0862779871>id("a1052526952").owner(AbstractSourceLegendTemplate.this));
		if (_45_1_0862779871 != null) _45_58_11647597214 = _45_1_0862779871._45_58_11647597214;
		if (_45_1_0862779871 != null) _45_181_0604353253 = _45_1_0862779871._45_181_0604353253;
		if (_46_1_11332481393 == null) _46_1_11332481393 = register(new _46_1_11332481393(box()).<_46_1_11332481393>id("a1995424392").owner(AbstractSourceLegendTemplate.this));
		if (_46_1_11332481393 != null) _46_58_11593277622 = _46_1_11332481393._46_58_11593277622;
		if (_46_1_11332481393 != null) _46_181_12119083845 = _46_1_11332481393._46_181_12119083845;
	}

	public class _44_1_01300019320 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public SourceLegendTemplate._44_1_01300019320. _44_58_11953754543 _44_58_11953754543;
		public SourceLegendTemplate._44_1_01300019320. _44_181_0845344845 _44_181_0845344845;

		public _44_1_01300019320(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_44_58_11953754543 == null) _44_58_11953754543 = register(new _44_58_11953754543(box()).<_44_58_11953754543>id("a_826205566").owner(AbstractSourceLegendTemplate.this));
			if (_44_181_0845344845 == null) _44_181_0845344845 = register(new _44_181_0845344845(box()).<_44_181_0845344845>id("a418535021").owner(AbstractSourceLegendTemplate.this));
		}

		public class _44_58_11953754543 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public _44_58_11953754543(B box) {
				super(box);
				_value("C");
			}

			@Override
			public void init() {
				super.init();
			}
			public _44_58_11953754543 textColor(String color) {
			    this._textColor(color);
			    this._refreshHighlight();
			    return this;
			}

			public _44_58_11953754543 backgroundColor(String color) {
			    this._backgroundColor(color);
			    this._refreshHighlight();
			    return this;
			}
		}

		public class _44_181_0845344845 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public _44_181_0845344845(B box) {
				super(box);
				_value("Category");
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}

	public class _45_1_0862779871 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public SourceLegendTemplate._45_1_0862779871. _45_58_11647597214 _45_58_11647597214;
		public SourceLegendTemplate._45_1_0862779871. _45_181_0604353253 _45_181_0604353253;

		public _45_1_0862779871(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_45_58_11647597214 == null) _45_58_11647597214 = register(new _45_58_11647597214(box()).<_45_58_11647597214>id("a_493673370").owner(AbstractSourceLegendTemplate.this));
			if (_45_181_0604353253 == null) _45_181_0604353253 = register(new _45_181_0604353253(box()).<_45_181_0604353253>id("a_2078036251").owner(AbstractSourceLegendTemplate.this));
		}

		public class _45_58_11647597214 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public _45_58_11647597214(B box) {
				super(box);
				_value("S");
			}

			@Override
			public void init() {
				super.init();
			}
			public _45_58_11647597214 textColor(String color) {
			    this._textColor(color);
			    this._refreshHighlight();
			    return this;
			}

			public _45_58_11647597214 backgroundColor(String color) {
			    this._backgroundColor(color);
			    this._refreshHighlight();
			    return this;
			}
		}

		public class _45_181_0604353253 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public _45_181_0604353253(B box) {
				super(box);
				_value("Selectable");
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}

	public class _46_1_11332481393 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public SourceLegendTemplate._46_1_11332481393. _46_58_11593277622 _46_58_11593277622;
		public SourceLegendTemplate._46_1_11332481393. _46_181_12119083845 _46_181_12119083845;

		public _46_1_11332481393(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_46_58_11593277622 == null) _46_58_11593277622 = register(new _46_58_11593277622(box()).<_46_58_11593277622>id("a_453470340").owner(AbstractSourceLegendTemplate.this));
			if (_46_181_12119083845 == null) _46_181_12119083845 = register(new _46_181_12119083845(box()).<_46_181_12119083845>id("a_256796276").owner(AbstractSourceLegendTemplate.this));
		}

		public class _46_58_11593277622 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public _46_58_11593277622(B box) {
				super(box);
				_value("T");
			}

			@Override
			public void init() {
				super.init();
			}
			public _46_58_11593277622 textColor(String color) {
			    this._textColor(color);
			    this._refreshHighlight();
			    return this;
			}

			public _46_58_11593277622 backgroundColor(String color) {
			    this._backgroundColor(color);
			    this._refreshHighlight();
			    return this;
			}
		}

		public class _46_181_12119083845 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public _46_181_12119083845(B box) {
				super(box);
				_value("Term");
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}

==> unit-1.1.7-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractSourceLegendTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractSourceLegendTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _44_1_01300019320 _44_1_01300019320;
	public SourceLegendTemplate._44_1_01300019320. _44_58_11953754543 _44_58_11953754543;
	public SourceLegendTemplate._44_1_01300019320. _44_181_0845344845 _44_181_0845344845;
	public _45_1_0862779871 _45_1_0862779871;
	public SourceLegendTemplate._45_1_0862779871. _45_58_11647597214 _45_58_11647597214;
	public SourceLegendTemplate._45_1_0862779871. _45_181_0604353253 _45_181_0604353253;
	public _46_1_11332481393 _46_1_11332481393;
	public SourceLegendTemplate._46_1_11332481393. _46_58_11593277622 _46_58_11593277622;
	public SourceLegendTemplate._46_1_11332481393. _46_181_12119083845 _46_181_12119083845;

    public AbstractSourceLegendTemplate(B box) {
        super(box);
        id("sourceLegendTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (_44_1_01300019320 == null) _44_1_01300019320 = register(new _44_1_01300019320(box()).<_44_1_01300019320>id("a_2051942081").owner(AbstractSourceLegendTemplate.this));
		if (_44_1_01300019320 != null) _44_58_11953754543 = _44_1_01300019320._44_58_11953754543;
		if (_44_1_01300019320 != null) _44_181_0845344845 = _44_1_01300019320._44_181_0845344845;
		if (_45_1_0862779871 == null) _45_1_0862779871 = register(new _45_1_0862779871(box()).<_45_1_0862779871>id("a1052526952").owner(AbstractSourceLegendTemplate.this));
		if (_45_1_0862779871 != null) _45_58_11647597214 = _45_1_0862779871._45_58_11647597214;
		if (_45_1_0862779871 != null) _45_181_0604353253 = _45_1_0862779871._45_181_0604353253;
		if (_46_1_11332481393 == null) _46_1_11332481393 = register(new _46_1_11332481393(box()).<_46_1_11332481393>id("a1995424392").owner(AbstractSourceLegendTemplate.this));
		if (_46_1_11332481393 != null) _46_58_11593277622 = _46_1_11332481393._46_58_11593277622;
		if (_46_1_11332481393 != null) _46_181_12119083845 = _46_1_11332481393._46_181_12119083845;
	}

    @Override
    public void remove() {
        super.remove();
	    if (_44_1_01300019320 != null) _44_1_01300019320.unregister();
	    if (_45_1_0862779871 != null) _45_1_0862779871.unregister();
	    if (_46_1_11332481393 != null) _46_1_11332481393.unregister();
	}

	public class _44_1_01300019320 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public SourceLegendTemplate._44_1_01300019320. _44_58_11953754543 _44_58_11953754543;
		public SourceLegendTemplate._44_1_01300019320. _44_181_0845344845 _44_181_0845344845;

		public _44_1_01300019320(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_44_58_11953754543 == null) _44_58_11953754543 = register(new _44_58_11953754543(box()).<_44_58_11953754543>id("a_826205566").owner(AbstractSourceLegendTemplate.this));
			if (_44_181_0845344845 == null) _44_181_0845344845 = register(new _44_181_0845344845(box()).<_44_181_0845344845>id("a418535021").owner(AbstractSourceLegendTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (_44_58_11953754543 != null) _44_58_11953754543.unregister();
			if (_44_181_0845344845 != null) _44_181_0845344845.unregister();
		}

		public class _44_58_11953754543 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public _44_58_11953754543(B box) {
				super(box);
				_value("C");
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
			public _44_58_11953754543 textColor(String color) {
			    this._textColor(color);
			    this._refreshHighlight();
			    return this;
			}

			public _44_58_11953754543 backgroundColor(String color) {
			    this._backgroundColor(color);
			    this._refreshHighlight();
			    return this;
			}
		}

		public class _44_181_0845344845 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public _44_181_0845344845(B box) {
				super(box);
				_value("Category");
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}
	}

	public class _45_1_0862779871 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public SourceLegendTemplate._45_1_0862779871. _45_58_11647597214 _45_58_11647597214;
		public SourceLegendTemplate._45_1_0862779871. _45_181_0604353253 _45_181_0604353253;

		public _45_1_0862779871(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_45_58_11647597214 == null) _45_58_11647597214 = register(new _45_58_11647597214(box()).<_45_58_11647597214>id("a_493673370").owner(AbstractSourceLegendTemplate.this));
			if (_45_181_0604353253 == null) _45_181_0604353253 = register(new _45_181_0604353253(box()).<_45_181_0604353253>id("a_2078036251").owner(AbstractSourceLegendTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (_45_58_11647597214 != null) _45_58_11647597214.unregister();
			if (_45_181_0604353253 != null) _45_181_0604353253.unregister();
		}

		public class _45_58_11647597214 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public _45_58_11647597214(B box) {
				super(box);
				_value("S");
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
			public _45_58_11647597214 textColor(String color) {
			    this._textColor(color);
			    this._refreshHighlight();
			    return this;
			}

			public _45_58_11647597214 backgroundColor(String color) {
			    this._backgroundColor(color);
			    this._refreshHighlight();
			    return this;
			}
		}

		public class _45_181_0604353253 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public _45_181_0604353253(B box) {
				super(box);
				_value("Selectable");
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}
	}

	public class _46_1_11332481393 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public SourceLegendTemplate._46_1_11332481393. _46_58_11593277622 _46_58_11593277622;
		public SourceLegendTemplate._46_1_11332481393. _46_181_12119083845 _46_181_12119083845;

		public _46_1_11332481393(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_46_58_11593277622 == null) _46_58_11593277622 = register(new _46_58_11593277622(box()).<_46_58_11593277622>id("a_453470340").owner(AbstractSourceLegendTemplate.this));
			if (_46_181_12119083845 == null) _46_181_12119083845 = register(new _46_181_12119083845(box()).<_46_181_12119083845>id("a_256796276").owner(AbstractSourceLegendTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (_46_58_11593277622 != null) _46_58_11593277622.unregister();
			if (_46_181_12119083845 != null) _46_181_12119083845.unregister();
		}

		public class _46_58_11593277622 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public _46_58_11593277622(B box) {
				super(box);
				_value("T");
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
			public _46_58_11593277622 textColor(String color) {
			    this._textColor(color);
			    this._refreshHighlight();
			    return this;
			}

			public _46_58_11593277622 backgroundColor(String color) {
			    this._backgroundColor(color);
			    this._refreshHighlight();
			    return this;
			}
		}

		public class _46_181_12119083845 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public _46_181_12119083845(B box) {
				super(box);
				_value("Term");
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}
	}
}
